@@ -18,8 +18,8 @@ export class HostService {
 
   constructor(private http: HttpClient, private deviceService: DeviceService) {}
 
-  list() {
-    return this.http.get(this.baseURL);
+  list(): Observable<object[]> {
+    return this.http.get<object[]>(this.baseURL);
   }
 
   create(hostname: string) {
@@ -43,4 +43,12 @@ export class HostService {
   getDaemons(hostname: string): Observable<Daemon[]> {
     return this.http.get<Daemon[]>(`${this.baseURL}/${hostname}/daemons`);
   }
+
+  getLabels(): Observable<string[]> {
+    return this.http.get<string[]>('ui-api/host/labels');
+  }
+
+  update(hostname: string, labels: string[]) {
+    return this.http.put(`${this.baseURL}/${hostname}`, { labels: labels });
+  }
 }
